==> istio-model-v1beta1-6.8.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/PortFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PortFluent<A extends PortFluent<A>> extends BaseFluent<A>{
  public PortFluent() {
  }
  public PortFluent(Port instance) {
    instance = (instance != null ? instance : new Port());

    if (instance != null) {
      this.withName(instance.getName());
      this.withNumber(instance.getNumber());
      this.withProtocol(instance.getProtocol());
      this.withTargetPort(instance.getTargetPort());
      this.withName(instance.getName());
      this.withNumber(instance.getNumber());
      this.withProtocol(instance.getProtocol());
      this.withTargetPort(instance.getTargetPort());
    }
  }
  private String name;
  private Integer number;
  private String protocol;
  private Integer targetPort;
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public boolean hasName() {
    return this.name != null;
  }
  public Integer getNumber() {
    return this.number;
  }
  public A withNumber(Integer number) {
    this.number=number; return (A) this;
  }
  public boolean hasNumber() {
    return this.number != null;
  }
  public String getProtocol() {
    return this.protocol;
  }
  public A withProtocol(String protocol) {
    this.protocol=protocol; return (A) this;
  }
  public boolean hasProtocol() {
    return this.protocol != null;
  }
  public Integer getTargetPort() {
    return this.targetPort;
  }
  public A withTargetPort(Integer targetPort) {
    this.targetPort=targetPort; return (A) this;
  }
  public boolean hasTargetPort() {
    return this.targetPort != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PortFluent that = (PortFluent) o;
    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(number, that.number)) return false;

    if (!java.util.Objects.equals(protocol, that.protocol)) return false;

    if (!java.util.Objects.equals(targetPort, that.targetPort)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  number,  protocol,  targetPort,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (number != null) { sb.append("number:"); sb.append(number + ","); }
    if (protocol != null) { sb.append("protocol:"); sb.append(protocol + ","); }
    if (targetPort != null) { sb.append("targetPort:"); sb.append(targetPort); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/PortFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class PortFluent<A extends PortFluent<A>> extends BaseFluent<A>{
  public PortFluent() {
  }
  
  public PortFluent(Port instance) {
    this.copyInstance(instance);
  }
  private String name;
  private Integer number;
  private String protocol;
  private Integer targetPort;
  
  protected void copyInstance(Port instance) {
    instance = (instance != null ? instance : new Port());
  
    if (instance != null) {
        this.withName(instance.getName());
        this.withNumber(instance.getNumber());
        this.withProtocol(instance.getProtocol());
        this.withTargetPort(instance.getTargetPort());
        this.withName(instance.getName());
        this.withNumber(instance.getNumber());
        this.withProtocol(instance.getProtocol());
        this.withTargetPort(instance.getTargetPort());
      }
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public Integer getNumber() {
    return this.number;
  }
  
  public A withNumber(Integer number) {
    this.number=number; return (A) this;
  }
  
  public boolean hasNumber() {
    return this.number != null;
  }
  
  public String getProtocol() {
    return this.protocol;
  }
  
  public A withProtocol(String protocol) {
    this.protocol=protocol; return (A) this;
  }
  
  public boolean hasProtocol() {
    return this.protocol != null;
  }
  
  public Integer getTargetPort() {
    return this.targetPort;
  }
  
  public A withTargetPort(Integer targetPort) {
    this.targetPort=targetPort; return (A) this;
  }
  
  public boolean hasTargetPort() {
    return this.targetPort != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PortFluent that = (PortFluent) o;
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    if (!java.util.Objects.equals(number, that.number)) return false;
  
    if (!java.util.Objects.equals(protocol, that.protocol)) return false;
  
    if (!java.util.Objects.equals(targetPort, that.targetPort)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(name,  number,  protocol,  targetPort,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (number != null) { sb.append("number:"); sb.append(number + ","); }
    if (protocol != null) { sb.append("protocol:"); sb.append(protocol + ","); }
    if (targetPort != null) { sb.append("targetPort:"); sb.append(targetPort); }
    sb.append("}");
    return sb.toString();
  }
  

}
